@@ -25,8 +25,8 @@ class IdentityKey(models.Model):
     cipher = models.CharField(max_length=88)
     salt = models.CharField(max_length=44)
     active = models.BooleanField(default=False)
-    timestamp = models.CharField(max_length=100)
-    dt_timestamp = models.DateTimeField(auto_now_add=True)
+    timestamp = models.CharField(max_length=100) # unix timestamp
+    dt_timestamp = models.DateTimeField(auto_now_add=True) # date timestamp
 
     class Meta:
         constraints = [models.UniqueConstraint(fields=['keyId', 'user'], name='unique_identity_key')]
@@ -85,6 +85,7 @@ class EncryptionSenderKey(models.Model):
     step = models.IntegerField(default=0)
     user = models.ForeignKey(User, on_delete=models.CASCADE, related_name='encryptingSenderKeys')
     key = models.CharField(max_length=500)
+    dt_timestamp = models.DateTimeField(auto_now_add=True, blank=True, null=True)
 
     class Meta:
         constraints = [models.UniqueConstraint(fields=['partyId', 'chainId', 'user'], name='unique_esk')]
@@ -114,12 +115,17 @@ class DecryptionSenderKey(models.Model):
     forUser = models.ForeignKey(User, on_delete=models.CASCADE, related_name='receivedSenderKeys', null=True)
     ofOneTimeId = models.CharField(max_length=100, blank=True, null=True)
     forOneTimeId = models.CharField(max_length=100, blank=True, null=True)
+    dt_timestamp = models.DateTimeField(auto_now_add=True, blank=True, null=True)
 
 
 class PendingKey(models.Model):
+    """
+    A pending key object can be created if the sender key of a sticky session has not been uploaded to the server yet.
+    """
     user = models.ForeignKey(User, on_delete=models.CASCADE, related_name='sentPendingKeys')
     owner = models.ForeignKey(User, on_delete=models.CASCADE, related_name='pendingKeys')
     stickId = models.CharField(max_length=100)
+    dt_timestamp = models.DateTimeField(auto_now_add=True, blank=True, null=True)
 
 
 class Party(models.Model):
@@ -140,7 +146,7 @@ class Party(models.Model):
     user = models.ForeignKey(User, on_delete=models.CASCADE, blank=True, null=True, related_name='parties')
     individual = models.BooleanField(default=False)
     partyHash = models.CharField(max_length=128, blank=True, null=True)
-    timestamp = models.DateTimeField(auto_now_add=True, blank=True, null=True)
+    dt_timestamp = models.DateTimeField(auto_now_add=True, blank=True, null=True)
 
     def save(self, *args, **kwargs):
         if not self.id:
